@@ -5,12 +5,13 @@ use quote::{format_ident, quote};
 use syn::{AttributeArgs, Error, FnArg, ImplItem, ImplItemMethod, ItemImpl, ReturnType};
 
 use crate::{
-    common_args::{APIMethod, ParamIn},
+    common_args::{APIMethod, DefaultValue, MaximumValidator, MinimumValidator, ParamIn},
     error::GeneratorResult,
     utils::{
         convert_oai_path, get_crate_name, get_summary_and_description, optional_literal,
         parse_oai_attrs, remove_oai_attrs,
     },
+    validators::HasValidators,
 };
 
 #[derive(FromMeta)]
@@ -41,8 +42,29 @@ struct APIOperationParam {
     desc: Option<String>,
     #[darling(default)]
     deprecated: bool,
+    #[darling(default)]
+    default: Option<DefaultValue>,
+
+    #[darling(default)]
+    multiple_of: Option<SpannedValue<f64>>,
+    #[darling(default)]
+    maximum: Option<SpannedValue<MaximumValidator>>,
+    #[darling(default)]
+    minimum: Option<SpannedValue<MinimumValidator>>,
+    #[darling(default)]
+    max_length: Option<SpannedValue<usize>>,
+    #[darling(default)]
+    min_length: Option<SpannedValue<usize>>,
+    #[darling(default)]
+    pattern: Option<SpannedValue<String>>,
+    #[darling(default)]
+    max_items: Option<SpannedValue<usize>>,
+    #[darling(default)]
+    min_items: Option<SpannedValue<usize>>,
 }
 
+impl_has_validators!(APIOperationParam);
+
 struct Context {
     add_routes: IndexMap<String, Vec<TokenStream>>,
     operations: IndexMap<String, Vec<TokenStream>>,
@@ -71,7 +93,9 @@ pub(crate) fn generate(
         if let ImplItem::Method(method) = item {
             if let Some(operation_args) = parse_oai_attrs::<APIOperation>(&method.attrs)? {
                 if method.sig.asyncness.is_none() {
-                    return Err(Error::new_spanned(&method, "Must be asynchronous").into());
+                    return Err(
+                        Error::new_spanned(&method.sig.ident, "Must be asynchronous").into(),
+                    );
                 }
 
                 generate_operation(&mut ctx, &crate_name, operation_args, method)?;
@@ -95,7 +119,7 @@ pub(crate) fn generate(
             paths.push(quote! {
                 #crate_name::registry::MetaPath {
                     path: #path,
-                    operations: &[#(#operation),*],
+                    operations: ::std::vec![#(#operation),*],
                 }
             });
         }
@@ -131,9 +155,9 @@ pub(crate) fn generate(
         #item_impl
 
         impl #crate_name::API for #ident {
-            fn metadata() -> ::std::vec::Vec<#crate_name::registry::MetaAPI> {
+            fn meta() -> ::std::vec::Vec<#crate_name::registry::MetaAPI> {
                 ::std::vec![#crate_name::registry::MetaAPI {
-                    paths: &[#(#paths),*],
+                    paths: ::std::vec![#(#paths),*],
                 }]
             }
 
@@ -215,7 +239,7 @@ fn generate_operation(
             }
         };
         let pname = format_ident!("p{}", i);
-        let arg_ty = &pat.ty.clone();
+        let arg_ty = &pat.ty;
 
         let operation_param = parse_oai_attrs::<APIOperationParam>(&pat.attrs)?;
         remove_oai_attrs(&mut pat.attrs);
@@ -224,10 +248,17 @@ fn generate_operation(
             // is poem extractor
             Some(operation_param) if operation_param.extract => {
                 parse_args.push(quote! {
-                    let #pname = <#arg_ty as #crate_name::poem::FromRequest>::from_request(&request, &mut body).await?;
+                    let #pname = match <#arg_ty as #crate_name::poem::FromRequest>::from_request(&request, &mut body).await.map_err(#crate_name::poem::Error::from) {
+                        ::std::result::Result::Ok(value) => value,
+                        ::std::result::Result::Err(err) if <#res_ty as #crate_name::Response>::BAD_REQUEST_HANDLER => {
+                                return ::std::result::Result::Ok(<#res_ty as #crate_name::Response>::from_parse_request_error(err));
+                            },
+                        ::std::result::Result::Err(err) => return ::std::result::Result::Err(err),
+                    };
                 });
                 use_args.push(pname);
             }
+
             // is parameter
             Some(operation_param) => {
                 let param_oai_typename = match &operation_param.name {
@@ -264,42 +295,105 @@ fn generate_operation(
                     }
                 }
 
-                let parse_param = match param_in {
-                    ParamIn::Path => {
-                        quote!(#crate_name::param::parse_from_path(#param_oai_typename, &request, &query.0))
-                    }
-                    ParamIn::Query => {
-                        quote!(#crate_name::param::parse_from_query(#param_oai_typename, &request, &query.0))
-                    }
-                    ParamIn::Header => {
-                        quote!(#crate_name::param::parse_from_header(#param_oai_typename, &request, &query.0))
-                    }
-                    ParamIn::Cookie => {
-                        quote!(#crate_name::param::parse_from_cookie(#param_oai_typename, &request, &query.0))
-                    }
-                };
                 let meta_in = {
                     let ty = param_in.to_meta();
                     quote!(#crate_name::registry::MetaParamIn::#ty)
                 };
+                let validators_checker = operation_param
+                    .validators()
+                    .create_param_checker(&crate_name, &param_oai_typename)?;
+                let validators_update_meta = operation_param
+                    .validators()
+                    .create_update_meta(&crate_name, &arg_ty)?;
+
+                match &operation_param.default {
+                    Some(default_value) => {
+                        let default_value = match default_value {
+                            DefaultValue::Default => {
+                                quote!(<#arg_ty as ::std::default::Default>::default())
+                            }
+                            DefaultValue::Function(func_name) => quote!(#func_name()),
+                        };
+
+                        parse_args.push(quote! {
+                            let #pname = {
+                                let value = #crate_name::param::get(#param_oai_typename, #meta_in, &request, &query.0);
+                                let value = value.as_deref();
+                                match value {
+                                    Some(value) => {
+                                        match #crate_name::types::Type::parse_from_str(Some(value))
+                                                .map_err(|err| #crate_name::poem::Error::bad_request(#crate_name::ParseRequestError::ParseParam {
+                                                    name: #param_oai_typename,
+                                                    reason: err.into_message(),
+                                                }))
+                                        {
+                                            ::std::result::Result::Ok(value) => {
+                                                #validators_checker
+                                                value
+                                            },
+                                            ::std::result::Result::Err(err) if <#res_ty as #crate_name::Response>::BAD_REQUEST_HANDLER => {
+                                                return ::std::result::Result::Ok(<#res_ty as #crate_name::Response>::from_parse_request_error(err));
+                                            },
+                                            ::std::result::Result::Err(err) => return ::std::result::Result::Err(err),
+                                        }
+                                    }
+                                    None => #default_value,
+                                }
+                            };
+                        });
+                    }
+                    None => {
+                        parse_args.push(quote! {
+                            let #pname = {
+                                let value = #crate_name::param::get(#param_oai_typename, #meta_in, &request, &query.0);
+                                match #crate_name::types::Type::parse_from_str(value.as_deref())
+                                        .map_err(|err| #crate_name::poem::Error::bad_request(#crate_name::ParseRequestError::ParseParam {
+                                            name: #param_oai_typename,
+                                            reason: err.into_message(),
+                                        }))
+                                {
+                                    ::std::result::Result::Ok(value) => {
+                                        #validators_checker
+                                        value
+                                    },
+                                    ::std::result::Result::Err(err) if <#res_ty as #crate_name::Response>::BAD_REQUEST_HANDLER => {
+                                        return ::std::result::Result::Ok(<#res_ty as #crate_name::Response>::from_parse_request_error(err));
+                                    },
+                                    ::std::result::Result::Err(err) => return ::std::result::Result::Err(err),
+                                }
+                            };
+                        });
+                    }
+                }
+
+                let meta_arg_default = match &operation_param.default {
+                    Some(DefaultValue::Default) => quote! {
+                        ::std::option::Option::Some(<#arg_ty as ::std::default::Default>::default().to_value())
+                    },
+                    Some(DefaultValue::Function(func_name)) => quote! {
+                        ::std::option::Option::Some(#func_name().to_value())
+                    },
+                    None => quote!(::std::option::Option::None),
+                };
 
-                parse_args.push(quote! {
-                    let #pname = match #parse_param {
-                        ::std::result::Result::Ok(value) => value,
-                        ::std::result::Result::Err(err) if <#res_ty as #crate_name::Response>::BAD_REQUEST_HANDLER => {
-                            return ::std::result::Result::Ok(<#res_ty as #crate_name::Response>::from_parse_request_error(err));
-                        },
-                        ::std::result::Result::Err(err) => return ::std::result::Result::Err(err),
-                    };
-                });
                 use_args.push(pname);
 
                 let desc = optional_literal(&operation_param.desc);
                 let deprecated = operation_param.deprecated;
                 params_meta.push(quote! {
+                    #[allow(unused_mut)]
                     #crate_name::registry::MetaOperationParam {
                         name: #param_oai_typename,
-                        schema: <#arg_ty as #crate_name::types::Type>::DATA_TYPE,
+                        schema: {
+                            let mut schema_ref = <#arg_ty as #crate_name::types::Type>::schema_ref();
+
+                            if let #crate_name::registry::MetaSchemaRef::Inline(schema) = &mut schema_ref {
+                                schema.default = #meta_arg_default;
+                                #validators_update_meta
+                            }
+
+                            schema_ref
+                        },
                         in_type: #meta_in,
                         description: #desc,
                         required: <#arg_ty as #crate_name::types::Type>::IS_REQUIRED,
@@ -307,6 +401,7 @@ fn generate_operation(
                     }
                 });
             }
+
             // is request body
             None => {
                 if has_request_payload {
@@ -316,13 +411,19 @@ fn generate_operation(
                 }
 
                 parse_args.push(quote! {
-                    let #pname = <#arg_ty as #crate_name::Request>::from_request(&request, &mut body).await?;
+                    let #pname = match <#arg_ty as #crate_name::Request>::from_request(&request, &mut body).await {
+                        ::std::result::Result::Ok(value) => value,
+                        ::std::result::Result::Err(err) if <#res_ty as #crate_name::Response>::BAD_REQUEST_HANDLER => {
+                                return ::std::result::Result::Ok(<#res_ty as #crate_name::Response>::from_parse_request_error(err));
+                            },
+                        ::std::result::Result::Err(err) => return ::std::result::Result::Err(err),
+                    };
                 });
                 use_args.push(pname);
 
                 has_request_payload = true;
                 request_meta =
-                    quote!(::std::option::Option::Some(<#arg_ty as #crate_name::Request>::META));
+                    quote!(::std::option::Option::Some(<#arg_ty as #crate_name::Request>::meta()));
                 ctx.request_types.push(quote!(#arg_ty));
             }
         }
@@ -347,13 +448,13 @@ fn generate_operation(
 
     ctx.operations.entry(oai_path).or_default().push(quote! {
         #crate_name::registry::MetaOperation {
-            tags: &[#(#tags),*],
+            tags: ::std::vec![#(#tags),*],
             method: #crate_name::poem::http::Method::#http_method,
             summary: #summary,
             description: #description,
-            params: &[#(#params_meta),*],
+            params: ::std::vec![#(#params_meta),*],
             request: #request_meta,
-            responses: <#res_ty as #crate_name::Response>::META,
+            responses: <#res_ty as #crate_name::Response>::meta(),
             deprecated: #deprecated,
         }
     });
