@@ -1,6 +1,6 @@
 use darling::FromMeta;
 use inflector::Inflector;
-use proc_macro2::TokenStream;
+use proc_macro2::{Ident, Span, TokenStream};
 use quote::quote;
 use syn::{Meta, NestedMeta, Path};
 
@@ -87,24 +87,16 @@ impl FromMeta for PathList {
 }
 
 #[derive(Debug, Copy, Clone, FromMeta)]
+#[darling(rename_all = "lowercase")]
 pub(crate) enum APIMethod {
-    #[darling(rename = "get")]
     GET,
-    #[darling(rename = "post")]
     POST,
-    #[darling(rename = "put")]
     PUT,
-    #[darling(rename = "delete")]
     DELETE,
-    #[darling(rename = "head")]
     HEAD,
-    #[darling(rename = "options")]
     OPTIONS,
-    #[darling(rename = "connect")]
     CONNECT,
-    #[darling(rename = "patch")]
     PATCH,
-    #[darling(rename = "trace")]
     TRACE,
 }
 
@@ -146,3 +138,33 @@ impl ParamIn {
         }
     }
 }
+
+#[derive(Debug)]
+pub(crate) enum DefaultValue {
+    Default,
+    Function(Ident),
+}
+
+impl FromMeta for DefaultValue {
+    fn from_word() -> darling::Result<Self> {
+        Ok(DefaultValue::Default)
+    }
+
+    fn from_string(value: &str) -> darling::Result<Self> {
+        Ok(DefaultValue::Function(Ident::new(value, Span::call_site())))
+    }
+}
+
+#[derive(FromMeta)]
+pub(crate) struct MaximumValidator {
+    pub(crate) value: f64,
+    #[darling(default)]
+    pub(crate) exclusive: bool,
+}
+
+#[derive(FromMeta)]
+pub(crate) struct MinimumValidator {
+    pub(crate) value: f64,
+    #[darling(default)]
+    pub(crate) exclusive: bool,
+}
